/*
 $License:
    Copyright (C) 2011 InvenSense Corporation, All Rights Reserved.
 $
 */

/******************************************************************************
 *
 * $Id: ml_mputest.h 6108 2011-09-29 18:52:21Z mcaramello $
 *
 *****************************************************************************/

#ifndef _INV_MPUTEST_H_
#define _INV_MPUTEST_H_

#ifdef __cplusplus
extern "C" {
#endif

#include "mltypes.h"

/* user APIs */
/**
 *  @brief  Set the orientation of the acceleroemter Z axis as it will be
 *          expected when running the MPU Self Test.
 *          Specifies the orientation of the accelerometer Z axis : Z axis
 *          pointing upwards or downwards.
 *  @param  z_sign
 *              The sign of the accelerometer Z axis; valid values are +1 and
 *              -1 for +Z and -Z respectively.  Any other value will cause the
 *              setting to be ignored and an error code to be returned.
 *              Note that this setting is an override on top of the chip
 *              mounting matrix in use and its purpose is to allow the accel
 *              test to be run with the -Z axis facing up instead of +Z axis.
 *  @return INV_SUCCESS or a non-zero error code.
 */
inv_error_t inv_self_test_set_accel_z_orient(signed char z_sign);
/**
 *  @brief  Runs the MPU Self Test at MPL runtime (short version).
 *          If the DMP is operating, stops the DMP temporarely,
 *          runs the MPU Self Test, and re-starts the DMP.
 *
 *  @return INV_SUCCESS or a non-zero error code otherwise.
 */
inv_error_t inv_self_test_run(void);
/**
 *  @brief  Runs the MPU Calibration Test at MPL runtime (long version).
 *          If the DMP is operating, stops the DMP temporarely,
 *          runs the MPU Calibration Test, and re-starts the DMP.
 *
 *  @return INV_SUCCESS or a non-zero error code otherwise.
 */
inv_error_t inv_self_test_calibration_run(void);
/**
 *  @brief  Runs the MPU test for bias correction only at MPL runtime
 *          (the short version is run but test results are ignored).
 *          If the DMP is operating, stops the DMP temporarely,
 *          runs the bias calculation routines, and re-starts the DMP.
 *
 *  @return INV_SUCCESS or a non-zero error code otherwise.
 */
inv_error_t inv_self_test_bias_run(void);
/**
 *  @brief  Runs the Accelerometer Calibration Test at MPL runtime.
 *          If the DMP is operating, stops the DMP temporarely,
 *          runs the Accel Calibration Test, and re-starts the DMP.
 *
 *  @return INV_SUCCESS or a non-zero error code otherwise.
 */
inv_error_t inv_self_test_accel_z_run(void);

/* other functions */
#define inv_set_self_test_parameters inv_set_test_parameters

#ifdef __cplusplus
}
#endif

#endif /* _INV_MPUTEST_H_ */

