/*
 $License:
    Copyright (C) 2011 InvenSense Corporation, All Rights Reserved.
 $
 */
/******************************************************************************
 * $Id: msp430_sysclock.h $
 *****************************************************************************/
/**
 *  @defgroup MSP430 System Layer
 *  @brief  MSP430 System Layer APIs.
 *          To interface with any platform, eMPL needs access to various
 *          system layer functions.
 *
 *  @{
 *      @file       msp430_sysclock.h
 *      @brief      Functions to configure the MSP430 system clock to settings
 *                  required for eMPL.
 *      @details    ACLK, MCLK, and SMCLK are all sourced directly by the DCO.
 *                  The DCO frequency is set by multiplying the internal
 *                  32.768kHz oscillator, which may vary in performance between
 *                  multiple chips. This may be an issue for time-critical
 *                  tasks such as providing a baud rate reference.
 */
#ifndef _MSP430_SYSCLOCK_H_
#define _MSP430_SYSCLOCK_H_

/**
 *  @brief  Set the frequency of MCLK, SMCLK, and ACLK.
 *  The logic is based on examples from TI.
 *  @return 0 if successful.
 */
int msp430_configure_sysclock(void);

#endif  /* _MSP430_SYSCLOCK_H_ */

/**
 * @}
 */
