/*
 $License:
    Copyright (C) 2011 InvenSense Corporation, All Rights Reserved.
 $
 */
/******************************************************************************
 *
 * $Id: msp430_timer.c $
 *
 *****************************************************************************/

/**
 *  @defgroup MSP430 System Layer
 *  @brief  MSP430 System Layer APIs.
 *          To interface with any platform, eMPL needs access to various
 *			system layer functions.
 *
 *  @{
 *      @file       msp430_timer.h
 *      @brief      Time-related functions needed by eMPL.
 *      @details    This driver is meant for use on an MSP430F5438A or
 *                  MSP430F5529 with a sub-master clock sourced by the DCO at
 *                  12MHz. For other rates, the interrupt frequency needs to be
 *                  reconfigured.
 */
#ifndef _MSP430_TIMER_H_
#define _MSP430_TIMER_H_

#include <stdint.h>

/**
 *  @brief  Configure and start hardware clock.
 *
 *  This function causes Timer B0 to produce a timer overflow interrupt every
 *  millisecond. If SMCLK is not running at 12MHz, change TBCCR0 such that it
 *  represents the number of system ticks per millisecond.
 *
 *  @return 0 if successful.
 */
int msp430_clock_enable(void);
/**
 *  @brief      Get current clock count.
 *  Timer overflow will occur after 2^32 milliseconds. Oh no!
 *  @param[out] count   Timer count in milliseconds.
 *  return      0 if successful.
 */
int msp430_get_clock_count(uint32_t *count);

/**
 *  @brief      Perform a blocking delay.
 *  @param[in]  num_ms  Number of milliseconds to delay.
 *  @return     0 if successful.
 */
int msp430_delay_ms(uint32_t num_ms);

#endif  /* _MSP430_TIMER_H_ */
/**
 * @}
 */
